"""This is the 'nester.py' module, and it provides one function called print_lol() 
	which prints lists that may or may not include nested lists."""

def print_lol(the_list):
	"""This function takes a positional argument called "the_list", 
		which is any Python list (of, possibly, nested lists). 
		Each data item in the provided list is (recursively) printed to the screen on its own line."""
	for item in the_list:
		if isinstance(item, list):
			print_lol(item)
		else:
			print item

										
	


from distutils.core import setup

setup(
		name 			= 'egnester',
		version			= '1.0.0',
		py_modules		= ['egnester'],
		author			= 'ekramGaleti',
		author_email	= 'enigmaekkui@gmail.com',
		url				= 'www.perfectgirls.net',
		description		= 'Lists in Lists in Listes.......and so on',
)